# (doktor5000) this package buildrequires other packages for their original/untranslated man pages
# those are then used to check and generate the localised versions of the contained man pages
# missing original man pages, for which localised version would be present, can be checked e.g. via
# bl man-pages-de.spec 2>&1 | grep "could not be found" | sort -u

%define	LNG de
%define	srcname manpages-%{LNG}

Name:		man-pages-%{LNG}
Version:	1.11
Release:	%mkrel 1
Summary:	German man (manual) pages from the Linux Documentation Project
License:	GPLv3
Group:		System/Internationalization
Url:		http://alioth.debian.org/projects/manpages-%{LNG}/
BuildArch:	noarch

Source0:	http://manpages-de.alioth.debian.org/downloads/%{srcname}-%{version}.tar.xz
# adds xz support to po/generate-manpage.sh when checking for original man-pages
# FIXME: check again, should have been upstreamed already according to
# https://alioth.debian.org/plugins/scmgit/cgi-bin/gitweb.cgi?p=manpages-de/manpages-de.git;a=commit;h=79c39f7ecd846ff3c3e7450891adf012ed1d6177
Patch0:		man-pages-de-1.7-mga-check-for-xz-manpages.patch

BuildRequires:	man
BuildRequires:	man-db
BuildRequires:	po4a
BuildRequires:	grep
BuildRequires:	man-pages
BuildRequires:	cdrkit
BuildRequires:	findutils
BuildRequires:	groff-for-man
BuildRequires:	info
BuildRequires:	isdn4k-utils
BuildRequires:	isdn4k-utils-doc
BuildRequires:	isdn4k-utils-xtools
BuildRequires:	less
BuildRequires:	lilo
BuildRequires:	lilo-doc
BuildRequires:	man-pages
BuildRequires:	nfs-utils
BuildRequires:	parted
BuildRequires:	po4a
BuildRequires:	procps-ng
BuildRequires:	sysvinit-legacy-tools
BuildRequires:	util-linux
BuildRequires:	vorbis-tools
BuildRequires:	coreutils-doc
BuildRequires:	yum-utils
BuildRequires:	deltarpm
BuildRequires:	exif

Requires:	locales-%LNG
Requires:	man
Provides:	man-%LNG = %{version}-%{release}
Provides:	manpages-%LNG = %{version}-%{release}

%description
A large collection of man pages (reference material) from the Linux
Documentation Project (LDP), translated to German.  The man pages are
organized into the following sections:

        Section 1:  User commands (intro only)
        Section 2:  System calls
        Section 3:  Libc calls
        Section 4:  Devices (e.g., hd, sd)
        Section 5:  File formats and protocols (e.g., wtmp, %{_sysconfdir}/passwd,
                    nfs)
        Section 6:  Games (intro only)
        Section 7:  Conventions, macro packages, etc. (e.g., nroff, ascii)
        Section 8:  System administration (intro only)

%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1 -b .check-for-xz-manpages

cd po/man1
mv -f ncal.1.po cal.1.po

%build
%configure2_5x
%make

%install
%make_install

# create a mandb index for the below check
LANG=%LNG DESTDIR=%{buildroot} %{_bindir}/mandb %{buildroot}/%_mandir/%LNG
# basic check if any man pages have been generated at all
# checks that size of generated mandb index is nonzero	 
[[ -s %{buildroot}%{_mandir}/%{LNG}/index.db ]] && rm -f %{buildroot}%{_mandir}/%{LNG}/index.db || exit 1

%files
%doc AUTHORS CHANGES COPYRIGHT LICENSE README
%dir %{_mandir}/%{LNG}
# prevent conflicts with procps-ng >= 3.3.10, already contains translated man pages
%exclude %{_mandir}/%{LNG}/man1/free.1.*
%exclude %{_mandir}/%{LNG}/man1/uptime.1.*
%{_mandir}/%{LNG}/man*


%changelog
* Sat Mar 26 2016 tv <tv> 1.11-1.mga6
+ Revision: 995630
- new release

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Thu Dec 10 2015 doktor5000 <doktor5000> 1.9-1.mga6
+ Revision: 909336
- new version 1.9
- generate more localised man-pages based on:
  o isdn4k-utils
  o lilo-doc
  o yum-utils
  o deltarpm
  o exif
- re-add basic check if man pages have been generated
- added brief explanation how this package is built and how to check for

* Mon Nov 09 2015 tv <tv> 1.8-3.mga6
+ Revision: 900261
- drop support for makewhatis now that we use mandb

  + doktor5000 <doktor5000>
    - exclude free and uptime man pages to prevent conflicts with procps-ng >= 3.3.10

* Thu Nov 27 2014 akien <akien> 1.8-1.mga5
+ Revision: 799490
- Version 1.8

* Wed Oct 15 2014 umeabot <umeabot> 1.7-6.mga5
+ Revision: 747772
- Second Mageia 5 Mass Rebuild

* Sun Oct 05 2014 doktor5000 <doktor5000> 1.7-5.mga5
+ Revision: 736983
- add missing BuildRequires on coreutils-doc for more translated manpages

* Tue Sep 16 2014 umeabot <umeabot> 1.7-4.mga5
+ Revision: 682147
- Mageia 5 Mass Rebuild

* Mon Aug 25 2014 doktor5000 <doktor5000> 1.7-3.mga5
+ Revision: 667245
- fix po/generate-manpage.sh to also check for original .xz man-pages
  o man-pages-de-1.7-mga-check-for-xz-manpages.patch
  o drop tarball with Debian man-pages, use our original ma-pages
- change basic check to query if size of generated whatis index is nonzero

* Sun Aug 24 2014 doktor5000 <doktor5000> 1.7-2.mga5
+ Revision: 667236
- fix creation of man-pages (mga#13873)
  o sync with Fedora, thanks to Mario Bl?\195?\164ttermann
  o add tarball with missing man-pages from debian required for generation
- rename ncal.1.po to cal.1.po
- add basic test to check whether any manpages have been created at all
- add BuildRequires to generate more man-pages
- remove bogus %%postun - /var/catman is not used by man-pages-de

* Mon Aug 04 2014 akien <akien> 1.7-1.mga5
+ Revision: 659595
- Version 1.7

* Fri Oct 18 2013 umeabot <umeabot> 1.0-3.mga4
+ Revision: 507708
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.0-2.mga3
+ Revision: 359366
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 14 2012 obgr_seneca <obgr_seneca> 1.0-1.mga3
+ Revision: 260588
- New version

* Sun Dec 11 2011 obgr_seneca <obgr_seneca> 0.9-1.mga2
+ Revision: 180620
- new version 0.9
- new upstream url at debian alioth

* Mon Jan 10 2011 ahmad <ahmad> 0.5-8.mga1
+ Revision: 5473
- drop old versioned man requires, just 'man' is enough now
- imported package man-pages-de

